.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _tutorial:

canary: Accelerating Application Testing Across Platforms
=========================================================

A Flexible, Extensible, and Scalable Framework for Scientific Applications

**Authors**: Tim Fuller, Stuart Baxley, Mario LoPrinzi, Matt Mosby, Scot Swan

**Affiliation**: Sandia National Laboratories

.. toctree::
    :maxdepth: 1

    Introduction <intro>
    Getting started <basic>
    Parameterizing tests <parameterize>
    assets
    Test dependencies <dependencies>
    Resource allocation <resource>
    batch
